@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
- * Copyright  2001 Udaltsoft
+ * Copyright (C) 2001 Udaltsoft
  *
  * Written by Sergey V. Oudaltsov <svu@users.sourceforge.net>
  *
@@ -39,6 +39,8 @@
 #include "delayed-dialog.h"
 #include "gnome-settings-profile.h"
 
+static GsdKeyboardManager *manager = NULL;
+
 static XklEngine *xkl_engine;
 static XklConfigRegistry *xkl_registry = NULL;
 
@@ -131,6 +133,7 @@ apply_desktop_settings (void)
 	if (!inited_ok)
 		return;
 
+	gsd_keyboard_manager_apply_settings (manager);
 	gkbd_desktop_config_load_from_gconf (&current_config);
 	/* again, probably it would be nice to compare things
 	   before activating them */
@@ -217,7 +220,8 @@ apply_xkb_settings (void)
 	GConfClient *conf_client;
 	GkbdKeyboardConfig current_sys_kbd_config;
 	int group_to_activate = -1;
-	const char *gdm_layout;
+	char *gdm_layout;
+	char *s;
 
 	if (!inited_ok)
 		return;
@@ -229,14 +233,24 @@ apply_xkb_settings (void)
 	 * We clear gdm_keyboard_layout early, so we don't risk
 	 * recursion from gconf notification.
 	 */
-	gdm_layout = gdm_keyboard_layout;
+	gdm_layout = g_strdup (gdm_keyboard_layout);
 	gdm_keyboard_layout = NULL;
+
+	/* gdm's configuration and $GDM_KEYBOARD_LAYOUT separates layout and
+	 * variant with a space, but gconf uses tabs; so convert to be robust
+	 * with both */
+	for (s = gdm_layout; s && *s; ++s) {
+		if (*s == ' ') {
+			*s = '\t';
+		}
+	}
+
 	if (gdm_layout != NULL) {
 		GSList *layouts;
 		GSList *found_node;
 		int     max_groups;
 
-		max_groups = xkl_engine_get_max_num_groups (xkl_engine);
+		max_groups = MAX (xkl_engine_get_max_num_groups (xkl_engine), 1);
 		layouts = gconf_client_get_list (conf_client,
 						 GKBD_KEYBOARD_CONFIG_KEY_LAYOUTS,
 						 GCONF_VALUE_STRING, NULL);
@@ -247,7 +261,7 @@ apply_xkb_settings (void)
 		 * prevents the list from becoming full if the user has a habit
 		 * of selecting many different keyboard layouts in GDM. */
 
-		found_node = g_slist_find_custom (layouts, gdm_layout, g_strcmp0);
+		found_node = g_slist_find_custom (layouts, gdm_layout, (GCompareFunc) g_strcmp0);
 
 		if (!found_node) {
 			/* Insert at the last valid place, or at the end of
@@ -302,6 +316,8 @@ apply_xkb_settings (void)
 		}
 	}
 
+	g_free (gdm_layout);
+
 	if (!try_activating_xkb_config_if_new (&current_sys_kbd_config)) {
 		if (filter_xkb_config ()) {
 			if (!try_activating_xkb_config_if_new (&current_sys_kbd_config)) {
@@ -450,7 +466,8 @@ gsd_keyboard_new_device (XklEngine * engine)
 }
 
 void
-gsd_keyboard_xkb_init (GConfClient * client)
+gsd_keyboard_xkb_init (GConfClient * client,
+		       GsdKeyboardManager * kbd_manager)
 {
 	gnome_settings_profile_start (NULL);
 #ifdef GSDKX
@@ -458,6 +475,7 @@ gsd_keyboard_xkb_init (GConfClient * client)
 	logfile = fopen ("/tmp/gsdkx.log", "a");
 	xkl_set_log_appender (gsd_keyboard_log_appender);
 #endif
+	manager = kbd_manager;
 	gnome_settings_profile_start ("xkl_engine_get_instance");
 	xkl_engine = xkl_engine_get_instance (GDK_DISPLAY ());
 	gnome_settings_profile_end ("xkl_engine_get_instance");
@@ -522,6 +540,7 @@ gsd_keyboard_xkb_shutdown (void)
 
 	pa_callback = NULL;
 	pa_callback_user_data = NULL;
+	manager = NULL;
 
 	if (!inited_ok)
 		return;
