@@ -64,7 +64,7 @@
 #define MAX_VOLUME 65536.0
 
 #if defined(__OpenBSD__)
-# define EJECT_COMMAND "eject -t /dev/cd0"
+# define EJECT_COMMAND "eject -t /dev/rcd0c"
 #else
 # define EJECT_COMMAND "eject -T"
 #endif
@@ -618,11 +618,13 @@ update_dialog (GsdMediaKeysManager *manager,
                guint vol,
                gboolean muted)
 {
+        vol = (int) (100 * (double) vol / PA_VOLUME_NORM);
+        vol = CLAMP (vol, 0, 100);
+
         dialog_init (manager);
         gsd_media_keys_window_set_volume_muted (GSD_MEDIA_KEYS_WINDOW (manager->priv->dialog),
                                                 muted);
-        gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (manager->priv->dialog),
-                                                (int) (100 * (double)vol / PA_VOLUME_NORM));
+        gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (manager->priv->dialog), vol);
         gsd_media_keys_window_set_action (GSD_MEDIA_KEYS_WINDOW (manager->priv->dialog),
                                           GSD_MEDIA_KEYS_WINDOW_ACTION_VOLUME);
         dialog_show (manager);
@@ -689,7 +691,6 @@ do_sound_action (GsdMediaKeysManager *manager,
                         }
                 } else {
                         if (vol < MAX_VOLUME) {
-                                gboolean set;
                                 if (vol + norm_vol_step >= MAX_VOLUME) {
                                         vol = MAX_VOLUME;
                                 } else {
