@@ -450,7 +450,8 @@ is_laptop (GnomeOutputInfo *output)
         if (output->connected && output_name &&
             (strstr (output_name, "lvds")	||
              strstr (output_name, "LVDS")	||
-             strstr (output_name, "Lvds")))
+             strstr (output_name, "Lvds")       ||
+             strstr (output_name, "LCD")))
         {
                 return TRUE;
         }
@@ -655,12 +656,10 @@ make_laptop_setup (GnomeRRScreen *screen)
                 GnomeOutputInfo *info = result->outputs[i];
 
                 if (is_laptop (info)) {
-                        if (!info->on) {
-                                if (!turn_on (screen, info, 0, 0)) {
-                                        gnome_rr_config_free (result);
-                                        result = NULL;
-                                        break;
-                                }
+                        if (!turn_on (screen, info, 0, 0)) {
+                                gnome_rr_config_free (result);
+                                result = NULL;
+                                break;
                         }
                 }
                 else {
@@ -680,14 +679,8 @@ make_laptop_setup (GnomeRRScreen *screen)
 static int
 turn_on_and_get_rightmost_offset (GnomeRRScreen *screen, GnomeOutputInfo *info, int x)
 {
-        if (info->on) {
-                info->x = x;
-                info->y = 0;
+        if (turn_on (screen, info, x, 0))
                 x += info->width;
-        } else {
-                if (turn_on (screen, info, x, 0))
-                        x += info->width;
-        }
 
         return x;
 }
@@ -739,9 +732,8 @@ make_other_setup (GnomeRRScreen *screen)
                         info->on = FALSE;
                 }
                 else {
-                        if (info->connected && !info->on) {
+                        if (info->connected)
                                 turn_on (screen, info, 0, 0);
-                        }
                }
         }
 
@@ -1793,6 +1785,9 @@ status_icon_stop (GsdXrandrManager *manager)
                 g_signal_handlers_disconnect_by_func (
                         priv->status_icon, G_CALLBACK (status_icon_popup_menu_cb), manager);
 
+                /* hide the icon before unreffing it; otherwise we will leak
+                   whitespace in the notification area due to a bug in there */
+                gtk_status_icon_set_visible (priv->status_icon, FALSE);
                 g_object_unref (priv->status_icon);
                 priv->status_icon = NULL;
         }
